Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(222)

Unified Diff: content/public/common/resource_response_info.h

Issue 2516353002: Introduce url_list to the Response scheme of CacheStorage. (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/common/resource_response_info.h
diff --git a/content/public/common/resource_response_info.h b/content/public/common/resource_response_info.h
index 3e8618c3c2b832f32dda1d77094b47ace1593601..2afd20bd750fc7ccdbfb5dc3216890e3198e64ee 100644
--- a/content/public/common/resource_response_info.h
+++ b/content/public/common/resource_response_info.h
@@ -116,9 +116,9 @@ struct CONTENT_EXPORT ResourceResponseInfo {
// considering the CORS preflight logic.
bool was_fallback_required_by_service_worker;
// The original URL of the response which was fetched by the ServiceWorker.
falken 2016/11/30 14:57:37 change fetched to served?
horo 2016/12/01 07:42:13 Done.
// This may be empty if the response was created inside the ServiceWorker.
falken 2016/11/30 14:57:37 s/may be/is/ and add "or if the response was not s
horo 2016/12/01 07:42:13 Done.
- GURL original_url_via_service_worker;
+ std::vector<GURL> url_list_via_service_worker;
// The type of the response which was fetched by the ServiceWorker.
blink::WebServiceWorkerResponseType response_type_via_service_worker;
@@ -116,9 +116,9 @@ struct CONTENT_EXPORT ResourceResponseInfo {
// considering the CORS preflight logic.
bool was_fallback_required_by_service_worker;
- // The original URL of the response which was fetched by the ServiceWorker.
+ // The URL list of the response which was fetched by the ServiceWorker.
falken 2016/11/30 14:57:37 change fetched to served?
horo 2016/12/01 07:42:13 Done.

Powered by Google App Engine
This is Rietveld 408576698